DagmawiTime
-----------
To use (with caution), simply do::
Usage:
    import dagmawi_time
    time = dagmawi_time.DagmawiTime(00,00,00) #init time

    time.dispTime() #displays current time
    time.incHour() #increases hour by one

    time.dispTime()

For other functionality:
    use "dir(time)" to view other methods
